@@ -33,9 +33,6 @@ public:
     explicit BcdClockWidget(QWidget *parent = 0);
     ~BcdClockWidget();
 
-    void setLedSize(int size);
-    void setLedBorder(int border);
-    void setLedColor(const QColor &color);
     QSize sizeHint();
 
 protected slots:
