@@ -39,6 +39,11 @@ ClockWidget::~ClockWidget(){
     delete timer;
 }
 
+void ClockWidget::addBinaryDisplayWidget(BinaryDisplayWidget *widget, QLayout *layout){
+    connect(this, SIGNAL(settingsChanged()), widget, SLOT(applySettings()));
+    layout->addWidget(widget);
+}
+
 void ClockWidget::applySettings(){
     emit settingsChanged();
 }
