@@ -46,6 +46,9 @@ public:
     static const QString SHOW_SECONDS;
     static const bool SHOW_SECONDS_DEFAULT;
 
+    static const QString USE_GRAY_CODE;
+    static const bool USE_GRAY_CODE_DEFAULT;
+
 #ifndef Q_WS_MAEMO_5
     static const QString POSITION;
     static const QPoint POSITION_DEFAULT;
