@@ -27,37 +27,29 @@ UnixTimeBchWidget::UnixTimeBchWidget(QWidget *parent) :
     layout = new QHBoxLayout(this);
 
     eighthNibble = new VerticalBinaryDisplayWidget(4, 0);
-    connect(this, SIGNAL(settingsChanged()), eighthNibble, SLOT(applySettings()));
-    layout->addWidget(eighthNibble);
+    addBinaryDisplayWidget(eighthNibble, layout);
 
     seventhNibble = new VerticalBinaryDisplayWidget(4, 0);
-    connect(this, SIGNAL(settingsChanged()), seventhNibble, SLOT(applySettings()));
-    layout->addWidget(seventhNibble);
+    addBinaryDisplayWidget(seventhNibble, layout);
 
     sixthNibble = new VerticalBinaryDisplayWidget(4, 0);
-    connect(this, SIGNAL(settingsChanged()), sixthNibble, SLOT(applySettings()));
-    layout->addWidget(sixthNibble);
+    addBinaryDisplayWidget(sixthNibble, layout);
 
     fifthNibble = new VerticalBinaryDisplayWidget(4, 0);
-    connect(this, SIGNAL(settingsChanged()), fifthNibble, SLOT(applySettings()));
-    layout->addWidget(fifthNibble);
+    addBinaryDisplayWidget(fifthNibble, layout);
 
     fourthNibble = new VerticalBinaryDisplayWidget(4, 0);
-    connect(this, SIGNAL(settingsChanged()), fourthNibble, SLOT(applySettings()));
-    layout->addWidget(fourthNibble);
+    addBinaryDisplayWidget(fourthNibble, layout);
 
     thirdNibble = new VerticalBinaryDisplayWidget(4, 0);
-    connect(this, SIGNAL(settingsChanged()), thirdNibble, SLOT(applySettings()));
-    layout->addWidget(thirdNibble);
+    addBinaryDisplayWidget(thirdNibble, layout);
 
     if(showSeconds){
         secondNibble = new VerticalBinaryDisplayWidget(4, 0);
-        connect(this, SIGNAL(settingsChanged()), secondNibble, SLOT(applySettings()));
-        layout->addWidget(secondNibble);
+        addBinaryDisplayWidget(secondNibble, layout);
 
         firstNibble = new VerticalBinaryDisplayWidget(4, 0);
-        connect(this, SIGNAL(settingsChanged()), firstNibble, SLOT(applySettings()));
-        layout->addWidget(firstNibble);
+        addBinaryDisplayWidget(firstNibble, layout);
     }else{
         secondNibble = NULL;
         firstNibble = NULL;
