@@ -27,7 +27,7 @@ class VerticalBinaryDisplayWidget : public BinaryDisplayWidget
     Q_OBJECT
 
 public:
-    explicit VerticalBinaryDisplayWidget(int bits, int value = 0, int height = 0, QWidget *parent = 0);
+    explicit VerticalBinaryDisplayWidget(int bits, int value = 0, int widgetSize = 0, QWidget *parent = 0);
 
     QSize sizeHint();
 
